//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Furo](index.md)

# Furo

@Serializable

interface [Furo](index.md)

副露

#### Inheritors

| |
|---|
| [Chi](../-chi/index.md) |
| [Pon](../-pon/index.md) |
| [Kan](../-kan/index.md) |

## Types

| Name | Summary |
|---|---|
| [Companion](-companion/index.md) | [common]<br>object [Companion](-companion/index.md) |

## Properties

| Name | Summary |
|---|---|
| [tiles](tiles.md) | [common]<br>abstract val [tiles](tiles.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../-tile/index.md)&gt; |

## Functions

| Name | Summary |
|---|---|
| [asMentsu](as-mentsu.md) | [common]<br>abstract fun [asMentsu](as-mentsu.md)(): [Mentsu](../-mentsu/index.md)<br>获取副露的面子 |
